Module io

Module io 

This module contains a set of testing utilities of IO operations.

Functions

read_lines
Reads the contents of a file line by line using buffered I/O.
try_new_file
Creates a new file at the specified path and writes the given content to it.
try_new_tempfile
Creates a new temporary file and writes the given content into it.
try_remove_file
Attempts to remove a file at the specified path, retrying up to 4 times on failure.