Module rand

Module rand 

This module contains a set of testing utilities of random value generators.

Functions

generate
Generates a random value of type T.
generate_alphanumeric
Generates a random alphanumeric string of the specified length.
generate_badfile
Generates a random alphanumeric filename that does not exist in the current directory.
generate_bytes
Generates a vector of random bytes of the specified length.
generate_range
Generates a random value of type T within the specified range.