This module contains a set of testing utilities of IO operations.
Functions
- read_
lines - Reads the contents of a file line by line using buffered I/O.
- try_
new_ file - Creates a new file at the specified path and writes the given content to it.
- try_
new_ tempfile - Creates a new temporary file and writes the given content into it.
- try_
remove_ file - Attempts to remove a file at the specified path, retrying up to 4 times on failure.