This module contains a set of testing utilities of random value generators.
Functions
- generate
- Generates a random value of type
T. - generate_
alphanumeric - Generates a random alphanumeric string of the specified length.
- generate_
badfile - Generates a random alphanumeric filename that does not exist in the current directory.
- generate_
bytes - Generates a vector of random bytes of the specified length.
- generate_
range - Generates a random value of type
Twithin the specified range.